==> zetascale-2.1.1-py3-none-any.whl: zeta/ops/__init__.py <==
from zeta.ops.einops_from_to import EinopsToAndFrom
from zeta.ops.einops_poly import (
    rearrange_many,
    reduce_many,
    repeat_many,
)
from zeta.ops.main import (
    _matrix_inverse_root_newton,
    _matrix_root_eigen,
    channel_shuffle_new,
    compute_matrix_root_inverse_residuals,
    gram_matrix_new,
    img_compose_bw,
    img_compose_decompose,
    img_decompose,
    img_order_of_axes,
    img_transpose,
    img_transpose_2daxis,
    img_width_to_height,
    matrix_inverse_root,
    matrix_root_diagonal,
    merge_small_dims,
    multi_dim_cat,
    multi_dim_split,
    squeeze_2d_new,
    unsqueeze_2d_new,
)
from zeta.ops.mm_rearranges import (
    reshape_audio_to_text,
    reshape_img_to_text,
    reshape_text_to_img,
    reshape_video_to_text,
)
from zeta.ops.softmax import (
    fast_softmax,
    gumbelmax,
    local_softmax,
    logit_scaled_softmax,
    norm_exp_softmax,
    selu_softmax,
    sparse_softmax,
    sparsemax,
    standard_softmax,
    temp_softmax,
)
from zeta.ops.unitwise_norm import unitwise_norm
from zeta.ops.dilated_attn_ops import (
    padding_to_multiple_of,
    get_data_parallel_group,
    get_rank,
    get_world_size,
    get_data_parallel_rank,
    get_data_parallel_world_size,
    Allgather,
    all_gather_func,
)

from zeta.ops.absmax import absmax
from zeta.ops.misc_act import (
    VPGELU,
    VPReLU,
)
from zeta.ops.mm_softmax import mm_softmax

__all__ = [
    "EinopsToAndFrom",
    "rearrange_many",
    "reduce_many",
    "repeat_many",
    "reshape_audio_to_text",
    "reshape_img_to_text",
    "reshape_text_to_img",
    "reshape_video_to_text",
    "fast_softmax",
    "gumbelmax",
    "local_softmax",
    "logit_scaled_softmax",
    "norm_exp_softmax",
    "selu_softmax",
    "sparse_softmax",
    "sparsemax",
    "standard_softmax",
    "temp_softmax",
    "unitwise_norm",
    "matrix_inverse_root",
    "matrix_root_diagonal",
    "_matrix_root_eigen",
    "_matrix_inverse_root_newton",
    "compute_matrix_root_inverse_residuals",
    "merge_small_dims",
    "multi_dim_split",
    "multi_dim_cat",
    "img_transpose",
    "img_transpose_2daxis",
    "img_compose_bw",
    "img_decompose",
    "img_compose_decompose",
    "img_width_to_height",
    "img_order_of_axes",
    "gram_matrix_new",
    "channel_shuffle_new",
    "unsqueeze_2d_new",
    "squeeze_2d_new",
    "padding_to_multiple_of",
    "get_data_parallel_group",
    "get_rank",
    "get_world_size",
    "get_data_parallel_rank",
    "get_data_parallel_world_size",
    "Allgather",
    "all_gather_func",
    "absmax",
    "VPGELU",
    "VPReLU",
    "mm_softmax",
]

==> zetascale-2.1.8-py3-none-any.whl: zeta/ops/__init__.py <==
from zeta.ops.absmax import absmax
from zeta.ops.dilated_attn_ops import (
    Allgather,
    all_gather_func,
    get_data_parallel_group,
    get_data_parallel_rank,
    get_data_parallel_world_size,
    get_rank,
    get_world_size,
    padding_to_multiple_of,
)
from zeta.ops.einops_from_to import EinopsToAndFrom
from zeta.ops.einops_poly import rearrange_many, reduce_many, repeat_many
from zeta.ops.main import (
    _matrix_inverse_root_newton,
    _matrix_root_eigen,
    channel_shuffle_new,
    compute_matrix_root_inverse_residuals,
    gram_matrix_new,
    img_compose_bw,
    img_compose_decompose,
    img_decompose,
    img_order_of_axes,
    img_transpose,
    img_transpose_2daxis,
    img_width_to_height,
    matrix_inverse_root,
    matrix_root_diagonal,
    merge_small_dims,
    multi_dim_cat,
    multi_dim_split,
    squeeze_2d_new,
    unsqueeze_2d_new,
)
from zeta.ops.misc_act import VPGELU, VPReLU
from zeta.ops.mm_rearranges import (
    reshape_audio_to_text,
    reshape_img_to_text,
    reshape_text_to_img,
    reshape_video_to_text,
)
from zeta.ops.mm_softmax import mm_softmax
from zeta.ops.softmax import (
    fast_softmax,
    gumbelmax,
    local_softmax,
    logit_scaled_softmax,
    norm_exp_softmax,
    selu_softmax,
    sparse_softmax,
    sparsemax,
    standard_softmax,
    temp_softmax,
)
from zeta.ops.unitwise_norm import unitwise_norm

__all__ = [
    "EinopsToAndFrom",
    "rearrange_many",
    "reduce_many",
    "repeat_many",
    "reshape_audio_to_text",
    "reshape_img_to_text",
    "reshape_text_to_img",
    "reshape_video_to_text",
    "fast_softmax",
    "gumbelmax",
    "local_softmax",
    "logit_scaled_softmax",
    "norm_exp_softmax",
    "selu_softmax",
    "sparse_softmax",
    "sparsemax",
    "standard_softmax",
    "temp_softmax",
    "unitwise_norm",
    "matrix_inverse_root",
    "matrix_root_diagonal",
    "_matrix_root_eigen",
    "_matrix_inverse_root_newton",
    "compute_matrix_root_inverse_residuals",
    "merge_small_dims",
    "multi_dim_split",
    "multi_dim_cat",
    "img_transpose",
    "img_transpose_2daxis",
    "img_compose_bw",
    "img_decompose",
    "img_compose_decompose",
    "img_width_to_height",
    "img_order_of_axes",
    "gram_matrix_new",
    "channel_shuffle_new",
    "unsqueeze_2d_new",
    "squeeze_2d_new",
    "padding_to_multiple_of",
    "get_data_parallel_group",
    "get_rank",
    "get_world_size",
    "get_data_parallel_rank",
    "get_data_parallel_world_size",
    "Allgather",
    "all_gather_func",
    "absmax",
    "VPGELU",
    "VPReLU",
    "mm_softmax",
]
